summaryrefslogtreecommitdiffstats
path: root/src/gvcore/document.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gvcore/document.cpp')
-rw-r--r--src/gvcore/document.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gvcore/document.cpp b/src/gvcore/document.cpp
index 3069ae5..caa93f5 100644
--- a/src/gvcore/document.cpp
+++ b/src/gvcore/document.cpp
@@ -73,7 +73,7 @@ const char* CONFIG_SAVE_AUTOMATICALLY="save automatically";
/**
* Returns a widget suitable to use as a dialog tqparent
*/
static TQWidget* dialogParentWidget() {
return KApplication::kApplication()->mainWidget();
@@ -102,8 +102,8 @@ public:
// Document
//
//-------------------------------------------------------------------
-Document::Document(TQObject* tqparent)
-: TQObject(tqparent) {
+Document::Document(TQObject* parent)
+: TQObject(parent) {
d=new DocumentPrivate;
d->mModified=false;
d->mImpl=new DocumentEmptyImpl(this);
@@ -73,7 +73,7 @@ const char* CONFIG_SAVE_AUTOMATICALLY="save automatically";
/**
- * Returns a widget suitable to use as a dialog tqparent
+ * Returns a widget suitable to use as a dialog parent
*/
static TQWidget* dialogParentWidget() {